# This file was auto-generated by Fern from our API Definition.

import typing

NumericConversationField = typing.Union[
    typing.Literal[
        "ThumbsUpCount",
        "ThumbsDownCount",
        "InsertCount",
        "UserMessageCount",
        "HandleTime",
        "FirstResponseTime",
        "PredictedNPS",
    ],
    typing.Any,
]
