# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .browser_type import BrowserType


class BrowserInfo(UniversalBaseModel):
    type: BrowserType
    name: typing.Optional[str] = None
    version: typing.Optional[str] = None
    user_agent: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="userAgent")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
