# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .knowledge_base_version import KnowledgeBaseVersion


class KnowledgeBaseVersionsListResponse(UniversalBaseModel):
    knowledge_base_versions: typing_extensions.Annotated[
        typing.List[KnowledgeBaseVersion], FieldMetadata(alias="knowledgeBaseVersions")
    ] = pydantic.Field()
    """
    The active knowledge base versions for the knowledge base. Includes all versions within the last 90 days or the last 10, whichever is greater.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
