# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...commons.types.conversation_preview import ConversationPreview
from ...commons.types.page import Page
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ConversationsResponse(Page):
    conversations: typing.List[ConversationPreview] = pydantic.Field()
    """
    The conversations that match the search criteria
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
