# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .entity_id_filter import EntityIdFilter
from .user_data import UserData


class UserDataWithReference(UserData):
    user_id: typing_extensions.Annotated[EntityIdFilter, FieldMetadata(alias="userId")] = pydantic.Field()
    """
    Reverse index containing appId and referenceId data that identifies this app user
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
