# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...commons.types.base_paginated_request import BasePaginatedRequest
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from .conversation_field import ConversationField
from .conversation_filter import ConversationFilter


class ConversationsSearchRequest(BasePaginatedRequest):
    sort: typing.Optional[ConversationField] = None
    filter: typing.Optional[ConversationFilter] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
