# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ...commons.types.action_response import ActionResponse
from ...commons.types.page import Page
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs


class ActionsResponse(Page):
    actions: typing.List[ActionResponse] = pydantic.Field()
    """
    The actions that match the search criteria
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from ...commons.types.precondition_group import PreconditionGroup  # noqa: E402, F401, I001

update_forward_refs(ActionsResponse)
