# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...commons.types.page import Page
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from .agent_user import AgentUser


class AgentUserSearchResponse(Page):
    agent_users: typing_extensions.Annotated[typing.List[AgentUser], FieldMetadata(alias="agentUsers")] = (
        pydantic.Field()
    )
    """
    The agent users that match the search criteria
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
